# Code for the HTML ann viewer

* gatenlp-ann-viewer.html the HTML template 
* gatenlp-ann-viewer.js  the JavaScript code 
* gatenlp-ann-viewer-merged.js all Javascript code with dependencies, concatenated and possibly minified
* jquery-3.5.1.min.js the only dependency: jquery
* npm  the directory for updating npm 

